geo-coding
This is offline reverse geocoding crate that uses files derived from OSM data.
In memory the data is stored in a two-dimensional tree that enables efficient queruing for nearest neighbours.
The total size of all files related to Europe is around 200 MiB.
You can use geo-coding-cli utility to produce your own files for particular Earth regions or for the full planet.
Structs
- Tree2D
- Two-dimensional tree that maps a location given by
[C; 2]to a valueV.
Functions
- earth_
distance std - Returns geographical distance between two points.
- euclidean_
distance_ squared - Returns squared Euclidean distance between two points.
- orthogonal_
distance - Returns maximum distance between two points computed along each axis individually, i.e. $ \mathrm{max}\left(\left|x_1 - x_0\right|, \left|y_1 - y_0\right|\right) $.
Type Aliases
- Names
Tree - Two-dimensional tree that maps a location given by
[i64; 2]to a string.