earth_distance

Function earth_distance 

pub fn earth_distance(a: &[i64; 2], b: &[i64; 2]) -> u64
Available on crate feature std only.
Returns geographical distance between two points.

The first coordinate is longitude, the second coordinate is latitude. Both are in nanodegrees.

The distance is computed by converting each point to surface normals.

References